@@ -3,7 +3,9 @@ from typing import Optional
 
 from requests import Session
 from requests.adapters import HTTPAdapter
-from requests.packages.urllib3.util.retry import Retry
+from urllib3 import Retry
+
+from kentik_api.auth.auth import KentikAuth
 
 log = logging.getLogger(__name__)
 
@@ -25,3 +27,17 @@ class RetryableSession(Session):
         self.mount("https://", adapter)
         self.mount("http://", adapter)
         log.debug("%s: retry_strategy: %s", self.__class__, retry_strategy)
+
+
+def prepare_kentik_api_http_session(
+    auth_email: str,
+    auth_token: str,
+    retry_strategy: Optional[Retry],
+    proxy: Optional[str],
+) -> RetryableSession:
+    session = RetryableSession(retry_strategy)
+    session.auth = KentikAuth(auth_email, auth_token)
+    session.headers.update({"Content-Type": "application/json"})
+    if proxy:
+        session.proxies = dict(http=proxy, https=proxy)
+    return session
